@@ -2,7 +2,7 @@
  * gbsplay is a Gameboy sound player
  *
  * 2003-2005 (C) by Tobias Diedrich <ranma+gbsplay@tdiedrich.de>
- * Licensed under GNU GPL.
+ * Licensed under GNU GPL v1 or, at your option, any later version.
  */
 
 #ifndef _COMMON_H_
@@ -19,6 +19,15 @@
 #define false (!true)
 #endif
 
+#define WARN_N(n, ...) { \
+	static long ctr = n; \
+	if (ctr) { \
+		ctr--; \
+		fprintf(stderr, __VA_ARGS__); \
+	} \
+}
+#define WARN_ONCE(...) WARN_N(1, __VA_ARGS__)
+
 #define TEXTDOMAIN "gbsplay"
 #define N_(x) x
 
