@@ -1,9 +1,9 @@
 /*
  * gbsplay is a Gameboy sound player
  *
- * 2003-2005,2013 (C) by Tobias Diedrich <ranma+gbsplay@tdiedrich.de>
- *                       Christian Garbs <mitch@cgarbs.de>
- * Licensed under GNU GPL.
+ * 2003-2005,2013,2018 (C) by Tobias Diedrich <ranma+gbsplay@tdiedrich.de>
+ *                            Christian Garbs <mitch@cgarbs.de>
+ * Licensed under GNU GPL v1 or, at your option, any later version.
  */
 
 #include "common.h"
@@ -14,11 +14,23 @@
 
 #include "plugout.h"
 
+#ifdef PLUGOUT_ALSA
+extern const struct output_plugin plugout_alsa;
+#endif
 #ifdef PLUGOUT_DEVDSP
 extern const struct output_plugin plugout_devdsp;
 #endif
-#ifdef PLUGOUT_ALSA
-extern const struct output_plugin plugout_alsa;
+#ifdef PLUGOUT_DSOUND
+extern const struct output_plugin plugout_dsound;
+#endif
+#ifdef PLUGOUT_IODUMPER
+extern const struct output_plugin plugout_iodumper;
+#endif
+#ifdef PLUGOUT_MIDI
+extern const struct output_plugin plugout_midi;
+#endif
+#ifdef PLUGOUT_ALTMIDI
+extern const struct output_plugin plugout_altmidi;
 #endif
 #ifdef PLUGOUT_NAS
 extern const struct output_plugin plugout_nas;
@@ -29,36 +41,37 @@ extern const struct output_plugin plugout_pulse;
 #ifdef PLUGOUT_STDOUT
 extern const struct output_plugin plugout_stdout;
 #endif
-#ifdef PLUGOUT_MIDI
-extern const struct output_plugin plugout_midi;
-#endif
-#ifdef PLUGOUT_DSOUND
-extern const struct output_plugin plugout_dsound;
-#endif
 
 typedef /*@null@*/ const struct output_plugin* output_plugin_const_t;
 
+/* in order of preference, see also PLUGOUT_DEFAULT in plugout.h */
 static output_plugin_const_t plugouts[] = {
-#ifdef PLUGOUT_NAS
-	&plugout_nas,
-#endif
-#ifdef PLUGOUT_DEVDSP
-	&plugout_devdsp,
-#endif
-#ifdef PLUGOUT_ALSA
-	&plugout_alsa,
-#endif
-#ifdef PLUGOUT_STDOUT
-	&plugout_stdout,
+#ifdef PLUGOUT_DSOUND
+	&plugout_dsound,
 #endif
 #ifdef PLUGOUT_PULSE
 	&plugout_pulse,
 #endif
+#ifdef PLUGOUT_ALSA
+	&plugout_alsa,
+#endif
+#ifdef PLUGOUT_DEVDSP
+	&plugout_devdsp,
+#endif
+#ifdef PLUGOUT_STDOUT
+	&plugout_stdout,
+#endif
+#ifdef PLUGOUT_NAS
+	&plugout_nas,
+#endif
 #ifdef PLUGOUT_MIDI
 	&plugout_midi,
 #endif
-#ifdef PLUGOUT_DSOUND
-	&plugout_dsound,
+#ifdef PLUGOUT_ALTMIDI
+	&plugout_altmidi,
+#endif
+#ifdef PLUGOUT_IODUMPER
+	&plugout_iodumper,
 #endif
 	NULL
 };
@@ -75,7 +88,7 @@ regparm void plugout_list_plugins(void)
 	}
 
 	for (idx = 0; plugouts[idx] != NULL; idx++) {
-		printf("%s\t- %s\n", plugouts[idx]->name, plugouts[idx]->description);
+		printf("%-8s - %s\n", plugouts[idx]->name, plugouts[idx]->description);
 	}
 	(void)puts("");
 }
