@@ -5,9 +5,10 @@
  *
  * MIDI output plugin
  *
- * 2008 (C) by Vegard Nossum
+ * 2008,2018 (C) by Vegard Nossum
+ *                  Christian Garbs <mitch@cgarbs.de>
  *
- * Licensed under GNU GPL.
+ * Licensed under GNU GPL v1 or, at your option, any later version.
  */
 
 #include "common.h"
@@ -39,6 +40,8 @@ static long track_length_offset;
 
 static long cycles_prev = 0;
 
+static int note[4] = {0, 0, 0, 0};
+
 static int midi_write_u32(uint32_t x)
 {
 	uint8_t s[4];
@@ -201,28 +204,49 @@ static int regparm midi_skip(int subsong)
 	return midi_open_track(subsong);
 }
 
-static int note_on(long cycles, int channel, int note, int velocity)
+static int note_on(long cycles, int channel, int new_note, int velocity)
 {
 	uint8_t event[3];
 
 	event[0] = 0x90 | channel;
-	event[1] = note;
+	event[1] = new_note;
 	event[2] = velocity;
 
 	if (midi_write_event(cycles, event, 3))
 		return 1;
 
+	note[channel] = new_note;
+
 	return 0;
 }
 
-static int note_off(long cycles, int channel, int note)
+static int note_off(long cycles, int channel)
 {
 	uint8_t event[3];
 
+	if (!note[channel])
+		return 0;
+
 	event[0] = 0x80 | channel;
-	event[1] = note;
+	event[1] = note[channel];
 	event[2] = 0;
 
+	if (midi_write_event(cycles, event, 3))
+		return 1;
+
+	note[channel] = 0;
+	
+	return 0;
+}
+
+static int pan(long cycles, int channel, int pan)
+{
+	uint8_t event[3];
+
+	event[0] = 0xb0 | channel;
+	event[1] = 0x0a;
+	event[2] = pan;
+
 	if (midi_write_event(cycles, event, 3))
 		return 1;
 
@@ -232,23 +256,64 @@ static int note_off(long cycles, int channel, int note)
 static int regparm midi_io(long cycles, uint32_t addr, uint8_t val)
 {
 	static long div[4] = {0, 0, 0, 0};
-	static long note[4] = {0, 0, 0, 0};
 	static int volume[4] = {0, 0, 0, 0};
+	static int running[4] = {0, 0, 0, 0};
+	static int master[4] = {0, 0, 0, 0};
 	int new_note;
 
 	long chan = (addr - 0xff10) / 5;
 
+	if (!file)
+		return 1;
+
 	switch (addr) {
 	case 0xff12:
 	case 0xff17:
-	case 0xff21:
 		volume[chan] = 8 * (val >> 4);
+		master[chan] = (val & 0xf8) != 0;
+		if (!master[chan] && running[chan]) {
+			/* DAC turned off, disable channel */
+			if (note_off(cycles, chan))
+				return 1;
+			running[chan] = 0;
+		}
+		if (volume[chan]) {
+			/* volume set to >0, restart current note */
+			if (running[chan] && !note[chan]) {
+				new_note = NOTE(2048 - div[chan]) + 21;
+				if (new_note < 0 || new_note >= 0x80)
+					break;
+				if (note_on(cycles, chan, new_note, volume[chan]))
+					return 1;
+			}
+		} else {
+			/* volume set to 0, stop note (if any) */
+			if (note_off(cycles, chan))
+				return 1;
+		}
 		break;
 	case 0xff13:
 	case 0xff18:
 	case 0xff1d:
 		div[chan] &= 0xff00;
 		div[chan] |= val;
+
+		if (running[chan]) {
+			new_note = NOTE(2048 - div[chan]) + 21;
+
+			if (new_note != note[chan]) {
+				/* portamento: retrigger with new note */
+				if (note_off(cycles, chan))
+					return 1;
+
+				if (new_note < 0 || new_note >= 0x80)
+					break;
+
+				if (note_on(cycles, chan, new_note, volume[chan]))
+					return 1;
+			}
+		}
+
 		break;
 	case 0xff14:
 	case 0xff19:
@@ -259,61 +324,110 @@ static int regparm midi_io(long cycles, uint32_t addr, uint8_t val)
 		new_note = NOTE(2048 - div[chan]) + 21;
 
 		/* Channel start trigger */
-		if (val & 0x80) {
-			if (note[chan]) {
-				if (note_off(cycles, chan, note[chan]))
-					return 1;
-			}
+		if ((val & 0x80) == 0x80) {
+			if (note_off(cycles, chan))
+				return 1;
 
 			if (new_note < 0 || new_note >= 0x80)
 				break;
 
-			if (note_on(cycles, chan, new_note, volume[chan]))
-				return 1;
-			note[chan] = new_note;
+			if (master[chan]) {
+				if (note_on(cycles, chan, new_note, volume[chan]))
+					return 1;
+				running[chan] = 1;
+			}
 		} else {
-			if (note_off(cycles, chan, note[chan]))
-				return 1;
-			note[chan] = 0;
+			if (running[chan]) {
+				if (new_note != note[chan]) {
+					/* portamento: retrigger with new note */
+					if (note_off(cycles, chan))
+						return 1;
+
+					if (new_note < 0 || new_note >= 0x80)
+						break;
+
+					if (note_on(cycles, chan, new_note, volume[chan]))
+						return 1;
+				}
+			}
 		}
 
 		break;
 	case 0xff1a:
-#if 0
-		if (val) {
-			if (note_on(cycles, 2, note[2], volume[2]))
-				return 1;
-		} else {
-			if (note_off(cycles, 2, note[2]))
+		master[2] = (val & 0x80) == 0x80;
+		if (!master[2] && running[2]) {
+			/* DAC turned off, disable channel */
+			if (note_off(cycles, 2))
 				return 1;
+			running[2] = 0;
 		}
-#endif
 		break;
 	case 0xff1c:
 		volume[2] = 32 * ((4 - (val >> 5)) & 3);
+		if (volume[2]) {
+			/* volume set to >0, restart current note */
+			if (running[2] && !note[2]) {
+				new_note = NOTE(2048 - div[chan]) + 21;
+				if (new_note < 0 || new_note >= 0x80)
+					break;
+				if (note_on(cycles, 2, new_note, volume[2]))
+					return 1;
+			}
+		} else {
+			/* volume set to 0, stop note (if any) */
+			if (note_off(cycles, 2))
+				return 1;
+		}
+		break;
+	case 0xff25:
+		for (chan = 0; chan < 4; chan++)
+			switch ((val >> chan) & 0x11) {
+			case 0x10:
+				pan(cycles, chan, 0);
+				break;
+			case 0x01:
+				pan(cycles, chan, 127);
+				break;
+			default:
+				pan(cycles, chan, 64);
+			}
+		break;
+	case 0xff26:
+		if ((val & 0x80) == 0) {
+			for (chan = 0; chan < 4; chan++) {
+				div[chan] = 0;
+				volume[chan] = 0;
+				running[chan] = 0;
+				master[chan] = 1;
+				if (note_off(cycles, 2))
+					return 1;
+			}
+		}
 		break;
 	}
 
 	return 0;
 }
 
-static ssize_t regparm midi_write(const void *buf, size_t count)
-{
-	return count;
-}
-
 static void regparm midi_close(void)
 {
-	if (file)
-		midi_close_track();
+	int chan;
+	
+	if (!file)
+		return;
+
+	for (chan = 0; chan < 4; chan++)
+		if (note_off(cycles_prev + 1, chan))
+			return;
+	
+	midi_close_track();
 }
 
 const struct output_plugin plugout_midi = {
 	.name = "midi",
-	.description = "MIDI sound driver",
+	.description = "MIDI file writer",
 	.open = midi_open,
 	.skip = midi_skip,
 	.io = midi_io,
-	.write = midi_write,
 	.close = midi_close,
 };
