@@ -2,7 +2,7 @@
  * gbsplay is a Gameboy sound player
  *
  * 2003 (C) by Christian Garbs <mitch@cgarbs.de>
- * Licensed under GNU GPL.
+ * Licensed under GNU GPL v1 or, at your option, any later version.
  *
  * This file contains various toolbox functions that
  * can be useful in different parts of gbsplay.
@@ -12,14 +12,14 @@
 #include "util.h"
 #include "test.h"
 
-extern inline long rand_long(long max)
+long rand_long(long max)
 /* return random long from [0;max[ */
 {
 	return (long) (((double)max)*rand()/(RAND_MAX+1.0));
 }
 
 void shuffle_long(long *array, long elements)
-/* shuffle an int array in place
+/* shuffle a long array in place
  * Fisher-Yates algorithm, see `perldoc -q shuffle` :-)  */
 {
 	long i, j, temp;
