@@ -2,13 +2,13 @@
  * gbsplay is a Gameboy sound player
  *
  * 2003 (C) by Christian Garbs <mitch@cgarbs.de>
- * Licensed under GNU GPL.
+ * Licensed under GNU GPL v1 or, at your option, any later version.
  */
 
 #ifndef _UTIL_H_
 #define _UTIL_H_
 
-inline long rand_long(long max);
+long rand_long(long max);
 void shuffle_long(long *array, long elements);
 
 #endif
